This folder contains examples of OpenFAST postprocessing:

- CPLambdaPitch: determine the CP-CT Lambda Pitch matrices of a turbine.
- ExcelFile: Generate, run and postprocess OpenFAST cases using an Excelfile which defines the parameters to change for each simulation
- ParametricStudy: Generate, run and postprocess OpenFAST simulations where the parameters of each cases are defined within a python loop
- PowerCurve: run a set of OpenFAST simulations to determine a power curve.
- RadialInterp: interpolate a timeseries to a given radial location based on OpenFAST radial node outputs.
- RadialPostPro: extract average OpenFAST outputs as function of the radial coordinates
- Remap: remap a dataframe: change names, and perform operations (e.g. change units, scale, combine signals)


Additional examples that are module specific:

- Hawc2ToBeamDyn: converts a hawc2 model to beamdyn (beta)


